@@ -13,10 +13,6 @@
 
 /* Modified from vshow.c by Eric Tsui, 12/25/1994. */
 
-#ifdef RCSID
-static char *RcsId[] = "@(#)$Revision: 5899 $";
-#endif
-
 #define VSET_INTERFACE
 #include "hdp.h"
 
@@ -57,19 +53,8 @@ dumpvd(int32       vd,
     int32       cnt1, cnt2;
     int32       cn = 0;
     int32       ret_value = SUCCEED;
-
-#if defined (MAC) || defined (macintosh) || defined (SYMANTEC_C) || defined(__APPLE__)
-	/* macintosh cannot handle >32K locals */
-    char *fields = (char *)HDmalloc(VSFIELDMAX*FIELDNAMELENMAX* sizeof(char));
-    char *flds = (char *)HDmalloc(VSFIELDMAX*FIELDNAMELENMAX* sizeof(char));
-
-    CHECK_ALLOC( fields, "fields", "dumpvd" );
-    CHECK_ALLOC( flds, "flds", "dumpvd" );
-
-#else /* !macintosh */
     char        fields[VSFIELDMAX*FIELDNAMELENMAX];
     char        flds[VSFIELDMAX*FIELDNAMELENMAX];
-#endif /* !macintosh */    
 
     /* inquire about vdata */
     if (FAIL == VSinquire(vd, &nv, &interlace, fields, &vsize, vdname))
@@ -486,18 +471,6 @@ done:
               HDfree((VOIDP)bb);
       }
     /* Normal cleanup */
-#if defined (MAC) || defined (macintosh) || defined (SYMANTEC_C) || defined(__APPLE__)
-   if(fields != NULL)
-   {
-      HDfree(fields);
-      fields = NULL;
-    } 
-   if(flds != NULL)
-   {
-      HDfree(flds);
-      fields = NULL;
-    } 
-#endif /* macintosh */
     
     return ret_value;
 }	/* dumpvd */
@@ -526,20 +499,8 @@ dumpattr(int32 vid,
     intn (*vfmtfn)(VOIDP, file_format_t ff, FILE *);
     intn          status;
     intn          ret_value = SUCCEED;
-
-#if defined (MAC) || defined (macintosh) || defined (SYMANTEC_C) || defined(__APPLE__)
-	/* macintosh cannot handle >32K locals */
-    char *name = (char *)HDmalloc((FIELDNAMELENMAX+1) * sizeof(char));
-    uint8 *attrbuf = (uint8 *)HDmalloc((BUFFER) * sizeof(uint8));
-
-    /* check if allocations fail, terminate hdp */
-    CHECK_ALLOC( name, "name", "dumpattr" );
-    CHECK_ALLOC( attrbuf, "attrbuf", "dumpattr" );
-
-#else /* !macintosh */
     char          name[FIELDNAMELENMAX+1];
     uint8         attrbuf[BUFFER];
-#endif /* !macintosh */    
 
     /* vdata or vgroup? */
     if (isvs) 
@@ -714,18 +675,6 @@ done:
               HDfree(buf);
       }
     /* Normal cleanup */
-#if defined (MAC) || defined (macintosh) || defined (SYMANTEC_C) || defined(__APPLE__)
-   if(name != NULL)
-   {
-      HDfree(name);
-      name = NULL;
-    } 
-   if(attrbuf != NULL)
-   {
-      HDfree(attrbuf);
-      attrbuf = NULL;
-    } 
-#endif /* macintosh */    
 
     return ret_value;
 }
